@@ -1,5 +1,17 @@
 ## ---- echo = FALSE, message = FALSE--------------------------------------
 knitr::opts_chunk$set(collapse = T, comment = "#>")
+
+# installing packages needed for this document
+# installing only if the package is not already available
+if (!require('httr')) {
+  install.packages('httr')
+}
+
+if (!require('mockr')) {
+  install.packages('mockr')
+}
+
+# loading stubthat
 library(stubthat)
 
 ## ------------------------------------------------------------------------
@@ -14,29 +26,43 @@ jedi_or_sith('Luke')
 jedi_or_sith_stub$f('Luke')
 
 ## ------------------------------------------------------------------------
-library('httr')
+library(httr) # provides the GET and status_code functions
+
+url_downloader <- function(url) GET(url)
 
 check_api_endpoint_status <- function(url) {
-  response <- GET(url)
+  response <- url_downloader(url)
   response_status <- status_code(response)
   ifelse(response_status == 200, 'up', 'down')
 }
 
 ## ------------------------------------------------------------------------
-stub_of_get <- stub(GET)
-stub_of_get$withArgs(url = 'good url')$returns('good response')
-stub_of_get$withArgs(url = 'bad url')$returns('bad response')
+url_downloader_stub <- stub(url_downloader)
+url_downloader_stub$withArgs(url = 'good url')$returns(200)
+url_downloader_stub$withArgs(url = 'bad url')$returns(404)
 
-stub_of_status_code <- stub(status_code)
-stub_of_status_code$withArgs(x = 'good response')$returns(200)
-stub_of_status_code$withArgs(x = 'bad response')$returns(400)
+# testthat package provides the expect_equal function
+# mockr package provides the with_mock function
 
-library('testthat')
-with_mock(GET = stub_of_get$f, status_code = stub_of_status_code$f,
-          expect_equal(check_api_endpoint_status('good url'), 'up'))
+check_api_endpoint_status_tester <- function(x) {
+  mockr::with_mock(url_downloader = url_downloader_stub$f,
+                   check_api_endpoint_status(x))
+}
 
-with_mock(GET = stub_of_get$f, status_code = stub_of_status_code$f,
-          expect_equal(check_api_endpoint_status('bad url'), 'down'))
+(testthat::expect_equal(check_api_endpoint_status_tester('good url'), 'up'))
+(testthat::expect_equal(check_api_endpoint_status_tester('bad url'),  'down'))
+
+## ----eval=FALSE----------------------------------------------------------
+#  f1 <- function(...) {
+#  
+#    {...some computation...}
+#  
+#    interim_val <- f2(...)
+#  
+#    {...more computation...}
+#  
+#    return(ans)
+#  }
 
 ## ----error=TRUE----------------------------------------------------------
 sum <- function(a, b = 1) return(a + b)
